pub trait ToBytes {
// Required method
fn to_bytes(self) -> Vec<u8> ⓘ;
}Expand description
Trait to convert to byte vec implement this to allow you struct to be used by builder
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".